==> openshift-model-whereabouts-6.0.0-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverlappingRangeIPReservationSpecFluentImpl<A extends OverlappingRangeIPReservationSpecFluent<A>> extends BaseFluent<A> implements OverlappingRangeIPReservationSpecFluent<A>{
  public OverlappingRangeIPReservationSpecFluentImpl() {
  }
  public OverlappingRangeIPReservationSpecFluentImpl(OverlappingRangeIPReservationSpec instance) {
    this.withContainerid(instance.getContainerid()); 
    this.withPodref(instance.getPodref()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String containerid;
  private String podref;
  private Map<String,Object> additionalProperties;
  public String getContainerid() {
    return this.containerid;
  }
  public A withContainerid(String containerid) {
    this.containerid=containerid; return (A) this;
  }
  public Boolean hasContainerid() {
    return this.containerid != null;
  }
  public String getPodref() {
    return this.podref;
  }
  public A withPodref(String podref) {
    this.podref=podref; return (A) this;
  }
  public Boolean hasPodref() {
    return this.podref != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OverlappingRangeIPReservationSpecFluentImpl that = (OverlappingRangeIPReservationSpecFluentImpl) o;
    if (containerid != null ? !containerid.equals(that.containerid) :that.containerid != null) return false;
    if (podref != null ? !podref.equals(that.podref) :that.podref != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerid,  podref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerid != null) { sb.append("containerid:"); sb.append(containerid + ","); }
    if (podref != null) { sb.append("podref:"); sb.append(podref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-whereabouts-6.7.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverlappingRangeIPReservationSpecFluentImpl<A extends OverlappingRangeIPReservationSpecFluent<A>> extends BaseFluent<A> implements OverlappingRangeIPReservationSpecFluent<A>{
  public OverlappingRangeIPReservationSpecFluentImpl() {
  }
  public OverlappingRangeIPReservationSpecFluentImpl(OverlappingRangeIPReservationSpec instance) {
    if (instance != null) {
      this.withContainerid(instance.getContainerid());
      this.withPodref(instance.getPodref());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String containerid;
  private String podref;
  private Map<String,Object> additionalProperties;
  public String getContainerid() {
    return this.containerid;
  }
  public A withContainerid(String containerid) {
    this.containerid=containerid; return (A) this;
  }
  public Boolean hasContainerid() {
    return this.containerid != null;
  }
  public String getPodref() {
    return this.podref;
  }
  public A withPodref(String podref) {
    this.podref=podref; return (A) this;
  }
  public Boolean hasPodref() {
    return this.podref != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverlappingRangeIPReservationSpecFluentImpl that = (OverlappingRangeIPReservationSpecFluentImpl) o;
    if (!java.util.Objects.equals(containerid, that.containerid)) return false;

    if (!java.util.Objects.equals(podref, that.podref)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerid,  podref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerid != null) { sb.append("containerid:"); sb.append(containerid + ","); }
    if (podref != null) { sb.append("podref:"); sb.append(podref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
